import unittest
from PySensorMQTT.sensors.temperature import TemperatureSensor
from PySensorMQTT.sensors.base import MqttParameters

class TestTemperatureSensor(unittest.TestCase):
    def test_generate_temperature(self):
        parameters: MqttParameters = {
            'sensor_name': 'temp_sensor',
            'broker': 'localhost',
            'port': 1883,
            'topic': 'sensor/temperature',
            'update_interval': 5,
            'sensor_type': 'temperature'
        }
        sensor = TemperatureSensor(parameters)
        temperature = sensor.generate_temperature()
        self.assertIsInstance(temperature, float)


from setuptools import setup, find_packages
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
setup(
    name='PySensor-MQTT',
    version='0.2.1',
    packages=find_packages(),
    install_requires=[
        'paho-mqtt',
    ],
    long_description=long_description,
    long_description_content_type='text/markdown',
    description='Biblioteca para simulação de sensores e publicação via MQTT',
    author='Raunick Vileforte Vieira Generoso',
    author_email='raunickbhdesign@gmail.com',
    url='https://github.com/raunick/sensor_library_mqtt',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
